#
# spec file for package python-hiredis
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-hiredis
Version:        2.2.2
Release:        3.3
Summary:        Python wrapper for hiredis
License:        BSD-3-Clause
URL:            https://github.com/redis/hiredis-py
Source:         https://files.pythonhosted.org/packages/source/h/hiredis/hiredis-%{version}.tar.gz
# PATCH-FIX-UPSTREAM drop-vendor-sources.patch gh#redis/hiredis-py#90 mcepl@suse.com
# Allow to use platform hiredis libs on build
Patch0:         drop-vendor-sources.patch
# PATCH-FIX-UPSTREAM 159-sdsalloc-to-alloc.patch gh#redis/hiredis-py#158 mcepl@suse.com
# Don't use sdsalloc, we actually don't need it
Patch1:         159-sdsalloc-to-alloc.patch
# PATCH-FIX-UPSTREAM 161-use-system-hiredis.patch gh#redis/hiredis-py#158 mcepl@suse.com
# use system hiredis instead
Patch2:         161-use-system-hiredis.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  hiredis-devel >= 1.0.0
BuildRequires:  python-rpm-macros
%python_subpackages

%description
Python wrapper for hiredis C connector.

%prep
%autosetup -p1 -n hiredis-%{version}

# Use system hiredis
rm -r vendor/hiredis

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

# %%check
# export PYTHONPATH=%%{buildroot}%%{$python_sitearch}
# %%python_exec test.py

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitearch}/hiredis
%{python_sitearch}/hiredis-%{version}*-info

%changelog
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sun Mar 19 2023 Matej Cepl <mcepl@suse.com>
- Replace 0001-Use-system-libhiredis.patch with
  the upstream provided (gh#redis/hiredis-py!161)
  161-use-system-hiredis.patch for proper use of the system
  hiredis library.
* Sat Mar 18 2023 Matej Cepl <mcepl@suse.com>
- Update to 2.2.2:
  - Reverting gcc -BSymbolic due to symbol collisions
  - Add pack_command to support writing via hiredis-py
  - Fixing broken windows builds on python < 3.8
  - Fix url in Issue tracker
  - Restores publishing of source distribution
  - Supporting hiredis 1.1.0
  - Modernizing: Restoring CI, Moving to pytest
  - Adding LICENSE to Repository
  - Python 3.11 trove, and links back to the project
  - Integrating release drafter
  - Implement pack_command that serializes redis-py command to
    the RESP bytes object.
- Add 159-sdsalloc-to-alloc.patch (gh#redis/hiredis-py#158),
  which replaces use of sdsalloc with plain alloc.
* Sat Jan 15 2022 Matthias Fehring <buschmann23@opensuse.org>
- Update to 2.0.0
  * Bump hiredis from 0.13.3 to 1.0.0 and consequently add support
    for RESP3 (see #104)
  * Add type hints (see #106)
  * Drop support for EOL Python versions 2.7, 3.4, and 3.5 (see #103)
- Drop obsolete patches
  * hiredis1.patch
  * bump_hiredis_0.14.1.patch
- Update patches
  * 0001-Use-system-libhiredis.patch
  * drop-vendor-sources.patch
* Mon Feb  1 2021 Markéta Machová <mmachova@suse.com>
- Update to 1.1.0
  * Allow "encoding" and "errors" attributes to be updated at runtime (see #96)
- Drop fix_build_dir_in_tests.patch
- Add hiredis1.patch to fix build with hiredis 1.0.0
- Add bump_hiredis_0.14.1.patch to allow using more recent (and
  without some CVEs) version of hiredis.
* Thu Jan 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.1:
  * Permit all allowed values of codec errors (see #86)
  * BUGFIX: READEME.md has UTF-8 characters, setup.py will fail on
    systems where the locale is not UTF-8. (see #89)
- Drop merged patch 0002-Fix-README.md-has-unicode.patch
* Tue Sep 17 2019 Matthias Fehring <buschmann23@opensuse.org>
- Added patch 0002-Fix-README.md-has-unicode.patch
  * wrong encoding is used when opening README.md in setup.py
* Mon Aug 26 2019 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.0.0
  * (BREAKING CHANGE) Add ability to control how unicode decoding
    errors are handled
  * Removed support for EOL Python 2.6, 3.2, and 3.3.
  * Upgrade hiredis to 0.13.3
  * Fix non-utf8 reply parsing causing segmentation fault in Python 3
  * Expose len method to retrieve the buffer length
  * Fix crash when custom exception raise error (on init)
  * Sort list of source files to allow reproducible building
- Drop obsolete patch reproducible-build.patch
- Added patch drop-vendor-sources.patch
  * the vendor directory appears empty
* Wed Aug 29 2018 tchvatal@suse.com
- Initial commit, possibly used by python-redis
- Add patch to use system hiredis package:
  * 0001-Use-system-libhiredis.patch
- Add two more patches from debian:
  * reproducible-build.patch
  * fix_build_dir_in_tests.patch
